@@ -65,6 +65,9 @@ class Parser:
     def switch_to(self, element: any) -> None:
         self.scraper.switch_to(element=element)
 
+    def screenshot(self, file: str) -> None:
+        self.scraper.screenshot(file=file)
+
     def freeze(self) -> None:
         self.scraper.freeze()
 
